@@ -22,6 +22,7 @@ def segment_lanes_rgb(rgb_image, image_backlight, image_tresholded):
        :rtype: list
         """
 
+
     # Parameters for frame and lane size and shape
     last_x = 1000
     min_frame_area = 49000
@@ -40,9 +41,9 @@ def segment_lanes_rgb(rgb_image, image_backlight, image_tresholded):
     # Get the contours of threshold image
     contours, hierarchy = cv2.findContours(image_tresholded, cv2.RETR_TREE, cv2.CHAIN_APPROX_SIMPLE)
 
-    # cv2.drawContours(rgb_image, contours, -1, (0, 0, 255), 3)
-    # cv2.imshow('', rgb_image)
-    # cv2.waitKey()
+    #cv2.drawContours(rgb_image, contours, -1, (0, 0, 255), 3)
+    #cv2.imshow('', image_tresholded)
+    #cv2.waitKey()
 
     # We temporary store the position, rgb and backlight roi in a list
     lanes = []
@@ -93,7 +94,7 @@ def segment_lanes_rgb(rgb_image, image_backlight, image_tresholded):
         lanes_roi_rgb.append([lane_position, lane[0]])
         lanes_roi_backlight.append([lane_position, lane[2]])
 
-    return lanes_roi_rgb, lanes_roi_backlight
+    return lanes_roi_rgb, lanes_roi_backlight, len(lanes)
 
 
 def segment_lanes_binary(lanes_roi_backlight):
@@ -141,8 +142,9 @@ def segment_lanes_binary(lanes_roi_backlight):
         lanes_roi_binary.append([lane[0], image_binary_lane])
     return lanes_roi_binary
 
+
 def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_lane, predicted_lanes, destination_path,
-                        y_position, experiment, dai, file_results):
+                        y_position, experiment, dai, file_results, report_path, report=True):
     """Threshold the leaves by finding and filtering the contours of the binary lane image.
 
        :param lanes_roi_binary: The lanes of the binary image as list of tuple(image, position).
@@ -183,6 +185,7 @@ def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_la
         # We get the corresponding RGB lane
         image_RGB_lane = lanes_roi_rgb[lane_id][1]
 
+
         # We get the corresponding Prediction lane
         image_prediction_lane = predicted_lanes[lane_id][1]
 
@@ -244,13 +247,11 @@ def segment_leaf_binary(lanes_roi_binary, lanes_roi_rgb, plate_id, leaves_per_la
                                            str(plate_id) + ';' + str(lanes_roi_rgb[lane_id][0]) + ';' + str(leaf_id) + ';' +
                                            str(percent_infection) + '\n')
 
-                    # We put a zero before the leaf number because of ordering later in excel
-                    # if int(leaf_counter) > 9:
-                    #     cv2.imwrite(path_single_leaf_binary + plate_id + str(leaf_counter) + ".tif", mask)
-                    # else:
-                    #     cv2.imwrite(path_single_leaf_binary + plate_id + '0' + str(leaf_counter) + ".tif", mask)
 
                     leaf_id += 1
 
         cv2.imwrite(destination_path + plate_id + '_' + str(lanes_roi_rgb[lane_id][0]) + '_leaf_predict.png', image_RGB_lane)
+        # if report:
+        #     cv2.imwrite(report_path + str(lanes_roi_rgb[lane_id][0]) + '_leaf.png', image_RGB_lane)
+
 
